ete2.treeview.drawer

Package ete2 :: Package treeview :: Module drawer |
[hide private]
[frames] | no frames]

# Module drawer

source code

Classes | [hide private]
| TreeImageProperties
| NewickDialog
| _MainApp
| _TableItem
| _PropModeChooser
| _PropertiesDialog
| _TextItem Manage faces on Scene
| _FaceItem Manage faces on Scene
| _NodeItem
| _SelectorItem
| _HighlighterItem
| _MainView
| _TreeScene

Functions | [hide private]
logger(level, *msg) Just to manage how to print messages | source code
show_tree(t, style=None, img_properties=None) Interactively shows a tree. | source code
render_tree(t, imgName, w=None, h=None, style=None, img_properties=None, header=None) Render tree image into a PNG file. | source code

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev90``'``
| USE_GL = `False`
| DEBUG = `0`
| _QApp = `None`
| _MIN_NODE_STYLE = ``{``'``bgcolor``'``:` `'``#FFFFFF``'``,` `'``draw_descendants``'``:` 1`...``
| __package__ = ``'``ete2.treeview``'``

Variables Details | [hide private]

  ### _MIN_NODE_STYLE Value:
      {'bgcolor': '#FFFFFF',
       'draw_descendants': 1,
       'faces': None,
       'fgcolor': '#0030c1',
       'hlwidth': 1,
       'hz_line_color': '#000000',
       'line_type': 0,
       'shape': 'sphere',
      ...